from selenium import webdriver
from selenium.webdriver.common.by import By
from selenium.webdriver.chrome.service import Service
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
import requests
import os
import time

# 검색 키워드 설정
keyword = input("검색할 키워드를 입력하세요 (예: '고양이'): ")

# 다운로드 폴더 경로 설정 (C:\Users\tunin\Downloads\images 내 검색 키워드 폴더)
download_folder = os.path.join("C:/Users/tunin/Downloads/images", keyword)
if not os.path.exists(download_folder):
    os.makedirs(download_folder)

# 크롬 드라이버 경로 명시
chrome_driver_path = "C:/chromedriver-win64/chromedriver.exe"  # 실제 경로 확인
service = Service(executable_path=chrome_driver_path)
options = webdriver.ChromeOptions()
# options.add_argument("--headless")  # 주석 처리: 브라우저를 띄워 확인
driver = webdriver.Chrome(service=service, options=options)

# 네이버 이미지 검색 URL
url = f"https://search.naver.com/search.naver?where=image&sm=tab_jum&query={keyword}"
driver.get(url)
print("페이지 로드 완료")

# "상업적 이용 가능" 옵션을 활성화 (WebDriverWait 사용)
try:
    commercial_filter = WebDriverWait(driver, 10).until(
        EC.element_to_be_clickable((By.CSS_SELECTOR, "a[aria-label='상업적 이용 가능']"))
    )
    commercial_filter.click()  # 상업적 이용 가능 클릭
    print("상업적 이용 가능 필터 활성화 완료")
except Exception as e:
    print("상업적 이용 가능 필터 클릭 실패:", e)

# 스크롤 다운으로 이미지 로드
for _ in range(5):
    driver.execute_script("window.scrollTo(0, document.body.scrollHeight);")
    time.sleep(2)

# 이미지 URL 추출 (src나 data-src 속성도 확인)
images = driver.find_elements(By.CSS_SELECTOR, "img[class*='thumb']")
image_urls = []

for img in images:
    img_url = img.get_attribute("src") or img.get_attribute("data-src")  # src 또는 data-src 속성 사용
    
    # 이미지 URL이 유효하고, http로 시작할 경우만 저장
    if img_url and img_url.startswith("http"):
        image_urls.append(img_url)

print(f"추출된 이미지 URL 개수: {len(image_urls)}")
if image_urls:
    print("첫 번째 URL 예시:", image_urls[0])

# 이미지 다운로드 (10장으로 변경)
headers = {
    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) Chrome/122.0.0.0",
    "Referer": "https://search.naver.com/"
}

for i, image_url in enumerate(image_urls[:10]): # 10장으로 변경
    try:
        print(f"다운로드 시도: {image_url}")
        response = requests.get(image_url, stream=True, timeout=10, headers=headers)
        print(f"응답 코드: {response.status_code}")
        if response.status_code == 200:
            file_path = os.path.join(download_folder, f"image_{i+1}.jpg")
            with open(file_path, "wb") as file:
                file.write(response.content)
            print(f"다운로드 완료: {file_path}")
        else:
            print(f"다운로드 실패 (상태 코드 {response.status_code}): {image_url}")
    except Exception as e:
        print(f"에러 발생: {e}")

# 드라이버 종료
driver.quit()

print(f"프로그램 종료. '{download_folder}' 폴더를 확인하세요!")